summaryrefslogtreecommitdiffstats
path: root/test/vds.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/vds.c')
-rw-r--r--test/vds.c15
1 files changed, 7 insertions, 8 deletions
diff --git a/test/vds.c b/test/vds.c
index c006673..e678e88 100644
--- a/test/vds.c
+++ b/test/vds.c
@@ -55,7 +55,7 @@ static const char *FILENAME[] = {"vds_virt_0", "vds_virt_1", "vds_src_0", "vds_
/* Print config directly to output */
#define PRINT_CONFIG(...) \
do { \
- HDprintf("Config: " __VA_ARGS__); \
+ printf("Config: " __VA_ARGS__); \
HDputs(""); \
} while (0)
@@ -80,11 +80,11 @@ char vds_test_str_g[128] = "";
/* Replacement for TEST_ERROR for non-verbose output */
#define TEST_ERROR_SUPPRESSED \
do { \
- HDprintf("Failed config: %s\nFailed test: %s\n", vds_config_str_g, vds_test_str_g); \
+ printf("Failed config: %s\nFailed test: %s\n", vds_config_str_g, vds_test_str_g); \
TEST_ERROR; \
} while (0)
/* Replacement for HDprintf for printing configuration for non-verbose output */
#define PRINT_CONFIG(...) \
do { \
HDsnprintf(vds_config_str_g, sizeof(vds_config_str_g), __VA_ARGS__); \
@@ -426,9 +426,8 @@ test_api_get_ex_dcpl(test_api_config_t config, hid_t fapl, hid_t dcpl, hid_t *ex
TEST_ERROR;
if (config == TEST_API_REOPEN_FILE) {
if (ninfo.meta_size.obj.heap_size != exp_meta_size) {
- HDprintf("VDS metadata size: %llu Expected: %llu\n",
- (long long unsigned)ninfo.meta_size.obj.heap_size,
- (long long unsigned)exp_meta_size);
+ printf("VDS metadata size: %llu Expected: %llu\n",
+ (long long unsigned)ninfo.meta_size.obj.heap_size, (long long unsigned)exp_meta_size);
TEST_ERROR;
}
}
@@ -12437,13 +12436,13 @@ main(void)
if (nerrors)
goto error;
- HDprintf("All virtual dataset tests passed.\n");
+ printf("All virtual dataset tests passed.\n");
h5_cleanup(FILENAME, fapl);
return EXIT_SUCCESS;
error:
nerrors = MAX(1, nerrors);
- HDprintf("***** %d VIRTUAL DATASET TEST%s FAILED! *****\n", nerrors, 1 == nerrors ? "" : "S");
+ printf("***** %d VIRTUAL DATASET TEST%s FAILED! *****\n", nerrors, 1 == nerrors ? "" : "S");
return EXIT_FAILURE;
} /* end main() */
@@ -80,11 +80,11 @@ char vds_test_str_g[128] = "";
TEST_ERROR; \
} while (0)
-/* Replacement for HDprintf for printing configuration for non-verbose output */
+/* Replacement for printf for printing configuration for non-verbose output */
#define PRINT_CONFIG(...) \
do { \